Struct ChainOutput
pub struct ChainOutput<T> {
tx_hash: HashBase<CoreWrapper<Keccak256Core>>,
output: Option<T>,
}Expand description
Represents an output of a write operation to the chain performed by the node.
This consists always of a transaction hash and an optional output T.
Operations that produce no useful output use () as T.
Fields
tx_hash: HashBase<CoreWrapper<Keccak256Core>>output: Option<T>Implementations
impl<T> ChainOutput<T>
impl<T> ChainOutput<T>
pub fn new(
tx_hash: HashBase<CoreWrapper<Keccak256Core>>,
output: T,
) -> ChainOutput<T>
pub fn new( tx_hash: HashBase<CoreWrapper<Keccak256Core>>, output: T, ) -> ChainOutput<T>
Creates a new ChainOutput with the given transaction hash and output.
pub fn tx_hash(&self) -> &HashBase<CoreWrapper<Keccak256Core>>
pub fn tx_hash(&self) -> &HashBase<CoreWrapper<Keccak256Core>>
Returns the transaction hash of the chain operation.
impl ChainOutput<()>
impl ChainOutput<()>
pub fn new_empty(
tx_hash: HashBase<CoreWrapper<Keccak256Core>>,
) -> ChainOutput<()>
pub fn new_empty( tx_hash: HashBase<CoreWrapper<Keccak256Core>>, ) -> ChainOutput<()>
Creates a new ChainOutput with the given transaction hash and no output.